:orphan:

.. _examples_gallery:

General examples
-------------------

General-purpose and introductory examples for scikit-image.

The `narrative documentation <../user_guide.html>`_ introduces
conventions and basic image manipulations.



.. raw:: html

    <div style='clear:both'></div>

Manipulating exposure and color channels
----------------------------------------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Color deconvolution consists of the separation of features by their colors.">

.. only:: html

    .. figure:: /auto_examples/color_exposure/images/thumb/sphx_glr_plot_ihc_color_separation_thumb.png

        :ref:`sphx_glr_auto_examples_color_exposure_plot_ihc_color_separation.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/color_exposure/plot_ihc_color_separation

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="There are many filters that are designed to work with gray-scale images but not with color imag...">

.. only:: html

    .. figure:: /auto_examples/color_exposure/images/thumb/sphx_glr_plot_adapt_rgb_thumb.png

        :ref:`sphx_glr_auto_examples_color_exposure_plot_adapt_rgb.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/color_exposure/plot_adapt_rgb

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Here, we use morphological reconstruction to create a background image, which we can subtract f...">

.. only:: html

    .. figure:: /auto_examples/color_exposure/images/thumb/sphx_glr_plot_regional_maxima_thumb.png

        :ref:`sphx_glr_auto_examples_color_exposure_plot_regional_maxima.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/color_exposure/plot_regional_maxima

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This examples enhances an image with low contrast, using a method called *local histogram equal...">

.. only:: html

    .. figure:: /auto_examples/color_exposure/images/thumb/sphx_glr_plot_local_equalize_thumb.png

        :ref:`sphx_glr_auto_examples_color_exposure_plot_local_equalize.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/color_exposure/plot_local_equalize

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example adjusts image contrast by performing a Gamma and a Logarithmic correction on the i...">

.. only:: html

    .. figure:: /auto_examples/color_exposure/images/thumb/sphx_glr_plot_log_gamma_thumb.png

        :ref:`sphx_glr_auto_examples_color_exposure_plot_log_gamma.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/color_exposure/plot_log_gamma

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This examples enhances an image with low contrast, using a method called *histogram equalizatio...">

.. only:: html

    .. figure:: /auto_examples/color_exposure/images/thumb/sphx_glr_plot_equalize_thumb.png

        :ref:`sphx_glr_auto_examples_color_exposure_plot_equalize.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/color_exposure/plot_equalize

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="It can be useful to artificially tint an image with some color, either to highlight particular ...">

.. only:: html

    .. figure:: /auto_examples/color_exposure/images/thumb/sphx_glr_plot_tinting_grayscale_images_thumb.png

        :ref:`sphx_glr_auto_examples_color_exposure_plot_tinting_grayscale_images.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/color_exposure/plot_tinting_grayscale_images
.. raw:: html

    <div style='clear:both'></div>

Edges and lines
---------------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="We use a marching squares method to find constant valued contours in an image. In ``skimage.mea...">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_contours_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_contours.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_contours

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The convex hull of a binary image is the set of pixels included in the smallest convex polygon ...">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_convex_hull_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_convex_hull.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_convex_hull

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The Canny filter is a multi-stage edge detector. It uses a filter based on the derivative of a ...">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_canny_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_canny.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_canny

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Marching cubes is an algorithm to extract a 2D surface mesh from a 3D volume. This can be conce...">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_marching_cubes_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_marching_cubes.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_marching_cubes

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The active contour model is a method to fit open or closed splines to lines or edges in an imag...">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_active_contours_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_active_contours.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_active_contours

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Edge operators are used in image processing within edge detection algorithms. They are discrete...">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_edge_filter_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_edge_filter.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_edge_filter

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to draw several different shapes:">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_shapes_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_shapes.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_shapes

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Example of generating random shapes with particular properties. ">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_random_shapes_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_random_shapes.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_random_shapes

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The Hough transform in its simplest form is a method to detect straight lines [1]_.">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_line_hough_transform_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_line_hough_transform.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_line_hough_transform

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to approximate (Douglas-Peucker algorithm) and subdivide (B-Splines) pol...">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_polygon_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_polygon.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_polygon

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The Hough transform in its simplest form is a `method to detect straight lines &lt;http://en.wikip...">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_circular_elliptical_hough_transform_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_circular_elliptical_hough_transform.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_circular_elliptical_hough_transform

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Skeletonization reduces binary objects to 1 pixel wide representations. This can be useful for ...">

.. only:: html

    .. figure:: /auto_examples/edges/images/thumb/sphx_glr_plot_skeleton_thumb.png

        :ref:`sphx_glr_auto_examples_edges_plot_skeleton.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/edges/plot_skeleton
.. raw:: html

    <div style='clear:both'></div>

Detection of features and objects
---------------------------------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The DAISY local image descriptor is based on gradient orientation histograms similar to the SIF...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_daisy_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_daisy.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_daisy

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The Histogram of Oriented Gradient (HOG) feature descriptor is popular for object detection [1]...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_hog_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_hog.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_hog

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Detect corner points using the Harris corner detector and determine the subpixel position of co...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_corner_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_corner.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_corner

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="We use template matching to identify the occurrence of an image patch (in this case, a sub-imag...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_template_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_template.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_template

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="We fill holes (i.e. isolated, dark spots) in an image using morphological reconstruction by ero...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_holes_and_peaks_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_holes_and_peaks.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_holes_and_peaks

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The CENSURE feature detector is a scale-invariant center-surround detector (CENSURE) that claim...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_censure_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_censure.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_censure

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to compute multi-block local binary pattern (MB-LBP) features as well as...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_multiblock_local_binary_pattern_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_multiblock_local_binary_pattern.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_multiblock_local_binary_pattern

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Haar-like features are simple digital image features that were introduced in a real-time face d...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_haar_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_haar.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_haar

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Blobs are bright on dark or dark on bright regions in an image. In this example, blobs are dete...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_blob_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_blob.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_blob

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates the ORB feature detection and binary description algorithm. It uses a...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_orb_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_orb.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_orb

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates the BRIEF binary description algorithm. The descriptor consists of re...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_brief_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_brief.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_brief

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="How to build a (bio-plausible) *sparse* dictionary (or &#x27;codebook&#x27;, or &#x27;filterbank&#x27;) for e.g. im...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_gabors_from_astronaut_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_gabors_from_astronaut.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_gabors_from_astronaut

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrates texture classification using grey level co-occurrence matrices (GLCMs)...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_glcm_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_glcm.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_glcm

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The shape index is a single valued measure of local curvature, derived from the eigen values of...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_shape_index_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_shape_index.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_shape_index

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Histogram matching can be used for object detection in images [1]_. This example extracts a sin...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_windowed_histogram_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_windowed_histogram.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_windowed_histogram

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we will see how to classify textures based on Gabor filter banks. Frequency an...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_gabor_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_gabor.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_gabor

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we will see how to classify textures based on LBP (Local Binary Pattern). LBP ...">

.. only:: html

    .. figure:: /auto_examples/features_detection/images/thumb/sphx_glr_plot_local_binary_pattern_thumb.png

        :ref:`sphx_glr_auto_examples_features_detection_plot_local_binary_pattern.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/features_detection/plot_local_binary_pattern
.. raw:: html

    <div style='clear:both'></div>

Filtering and restoration
-------------------------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The Frangi and hybrid Hessian filters can be used to detect continuous edges, such as vessels, ...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_frangi_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_frangi.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_frangi

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="*Hysteresis* is the lagging of an effect---a kind of inertia. In the context of thresholding, i...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_hysteresis_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_hysteresis.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_hysteresis

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we deconvolve a noisy version of an image using Wiener and unsupervised Wiener...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_restoration_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_restoration.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_restoration

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example compares the following mean filters of the rank filter package:">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_rank_mean_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_rank_mean.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_rank_mean

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The algorithm is based on a PSF (Point Spread Function), where PSF is described as the impulse ...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_deconvolution_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_deconvolution.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_deconvolution

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The reconstruction is supposed to be performed in fully automatic way by exploiting the informa...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_inpaint_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_inpaint.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_inpaint

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In information theory, information entropy is the log-base-2 of the number of possible outcomes...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_entropy_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_entropy.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_entropy

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we denoise a noisy version of a picture using the total variation, bilateral, ...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_denoise_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_denoise.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_denoise

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The discrete wavelet transform is not `shift-invariant`_.  Shift invariance can be achieved thr...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_cycle_spinning_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_cycle_spinning.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_cycle_spinning

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Some signals can only be observed modulo 2*pi, and this can also apply to two- and three dimens...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_phase_unwrap_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_phase_unwrap.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_phase_unwrap

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we denoise a detail of the astronaut image using the non-local means filter. T...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_nonlocal_means_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_nonlocal_means.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_nonlocal_means

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Wavelet denoising relies on the wavelet representation of the image. Gaussian noise tends to be...">

.. only:: html

    .. figure:: /auto_examples/filters/images/thumb/sphx_glr_plot_denoise_wavelet_thumb.png

        :ref:`sphx_glr_auto_examples_filters_plot_denoise_wavelet.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/filters/plot_denoise_wavelet
.. raw:: html

    <div style='clear:both'></div>

Operations on NumPy arrays
--------------------------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This script illustrates how to use basic NumPy operations, such as slicing, masking and fancy i...">

.. only:: html

    .. figure:: /auto_examples/numpy_operations/images/thumb/sphx_glr_plot_camera_numpy_thumb.png

        :ref:`sphx_glr_auto_examples_numpy_operations_plot_camera_numpy.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/numpy_operations/plot_camera_numpy

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrates the use of ``view_as_blocks`` from :py:func:`skimage.util`.  Block vie...">

.. only:: html

    .. figure:: /auto_examples/numpy_operations/images/thumb/sphx_glr_plot_view_as_blocks_thumb.png

        :ref:`sphx_glr_auto_examples_numpy_operations_plot_view_as_blocks.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/numpy_operations/plot_view_as_blocks
.. raw:: html

    <div style='clear:both'></div>

Segmentation of objects
-----------------------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Construct a region boundary RAG with the ``rag_boundary`` function. The function  :py:func:`ski...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_rag_boundary_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_rag_boundary.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_rag_boundary

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example constructs a Region Adjacency Graph (RAG) and recursively performs a Normalized Cu...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_ncut_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_ncut.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_ncut

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example constructs a Region Adjacency Graph (RAG) and merges regions which are similar in ...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_rag_mean_color_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_rag_mean_color.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_rag_mean_color

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The watershed transform is commonly used as a starting point for many segmentation algorithms. ...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_compact_watershed_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_compact_watershed.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_compact_watershed

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example constructs a Region Adjacency Graph (RAG) and draws it with the `rag_draw` method....">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_rag_draw_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_rag_draw.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_rag_draw

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Thresholding is used to create a binary image from a grayscale image [1]_.">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_thresholding_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_thresholding.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_thresholding

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The Chan-Vese segmentation algorithm is designed to segment objects without clearly defined bou...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_chan_vese_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_chan_vese.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_chan_vese

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The ``peak_local_max`` function returns the coordinates of local peaks (maxima) in an image. A ...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_peak_local_max_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_peak_local_max.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_peak_local_max

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Niblack and Sauvola thresholds are local thresholding techniques that are useful for images whe...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_niblack_sauvola_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_niblack_sauvola.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_niblack_sauvola

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to segment an image with image labelling. The following steps are applie...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_label_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_label.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_label

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to measure properties of labelled image regions.">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_regionprops_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_regionprops.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_regionprops

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The random walker algorithm [1]_  determines the segmentation of an image from a set of markers...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_random_walker_segmentation_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_random_walker_segmentation.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_random_walker_segmentation

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The watershed is a classical algorithm used for **segmentation**, that is, for separating diffe...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_watershed_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_watershed.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_watershed

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The watershed is a classical algorithm used for **segmentation**, that is, for separating diffe...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_marked_watershed_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_marked_watershed.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_marked_watershed

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example compares four popular low-level image segmentation methods.  As it is difficult to...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_segmentations_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_segmentations.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_segmentations

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="When segmenting an image, you may want to combine multiple alternative segmentations. The :py:f...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_join_segmentations_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_join_segmentations.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_join_segmentations

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates the use of the `merge_nodes` function of a Region Adjacency Graph (RA...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_rag_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_rag.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_rag

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example constructs a Region Adjacency Graph (RAG) and progressively merges regions that ar...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_rag_merge_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_rag_merge.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_rag_merge

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to perform hierarchical merging on region boundary Region Adjacen...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_boundary_merge_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_boundary_merge.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_boundary_merge

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="We detect local maxima in a galaxy image. The image is corrupted by noise, generating many loca...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_extrema_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_extrema.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_extrema

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="*Morphological Snakes* [1]_ are a family of methods for image segmentation. Their behavior is s...">

.. only:: html

    .. figure:: /auto_examples/segmentation/images/thumb/sphx_glr_plot_morphsnakes_thumb.png

        :ref:`sphx_glr_auto_examples_segmentation_plot_morphsnakes.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/segmentation/plot_morphsnakes
.. raw:: html

    <div style='clear:both'></div>

Geometrical transformations and registration
--------------------------------------------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Image swirling is a non-linear image deformation that creates a whirlpool effect.  This example...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_swirl_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_swirl.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_swirl

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="The ``pyramid_gaussian`` function takes an image and yields successive images shrunk by a const...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_pyramid_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_pyramid.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_pyramid

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrates the different edge modes available during interpolation in routines su...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_edge_modes_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_edge_modes.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_edge_modes

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="`Rescale` operation resizes an image by a given scaling factor. The scaling factor can either b...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_rescale_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_rescale.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_rescale

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to use the Piecewise Affine Transformation.">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_piecewise_affine_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_piecewise_affine.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_piecewise_affine

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example we see how to robustly fit a 3D line model to faulty data using the RANSAC algo...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_ransac3D_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_ransac3D.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_ransac3D

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how images can be resized using seam carving [1]_. Resizing to a new ...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_seam_carving_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_seam_carving.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_seam_carving

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example we see how to robustly fit a line model to faulty data using the RANSAC algorit...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_ransac_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_ransac.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_ransac

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="When comparing images, the mean squared error (MSE)--while simple to implement--is not highly i...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_ssim_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_ssim.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_ssim

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we use phase correlation to identify the relative shift between two similar-si...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_register_translation_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_register_translation.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_register_translation

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to robustly estimate epipolar geometry between two views using sp...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_fundamental_matrix_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_fundamental_matrix.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_fundamental_matrix

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In computed tomography, the tomography reconstruction problem is to obtain a tomographic slice ...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_radon_transform_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_radon_transform.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_radon_transform

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this simplified example we first generate two synthetic images as if they were taken from di...">

.. only:: html

    .. figure:: /auto_examples/transform/images/thumb/sphx_glr_plot_matching_thumb.png

        :ref:`sphx_glr_auto_examples_transform_plot_matching.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/transform/plot_matching
.. raw:: html

    <div style='clear:both'></div>

Longer examples and demonstrations
----------------------------------



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we will see how to use geometric transformations in the context of image proce...">

.. only:: html

    .. figure:: /auto_examples/xx_applications/images/thumb/sphx_glr_plot_geometric_thumb.png

        :ref:`sphx_glr_auto_examples_xx_applications_plot_geometric.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/xx_applications/plot_geometric

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Morphological image processing is a collection of non-linear operations related to the shape or...">

.. only:: html

    .. figure:: /auto_examples/xx_applications/images/thumb/sphx_glr_plot_morphology_thumb.png

        :ref:`sphx_glr_auto_examples_xx_applications_plot_morphology.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/xx_applications/plot_morphology

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we will see how to segment objects from a background. We use the ``coins`` ima...">

.. only:: html

    .. figure:: /auto_examples/xx_applications/images/thumb/sphx_glr_plot_coins_segmentation_thumb.png

        :ref:`sphx_glr_auto_examples_xx_applications_plot_coins_segmentation.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/xx_applications/plot_coins_segmentation

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Thresholding is used to create a binary image from a grayscale image [1]_. It is the simplest w...">

.. only:: html

    .. figure:: /auto_examples/xx_applications/images/thumb/sphx_glr_plot_thresholding_thumb.png

        :ref:`sphx_glr_auto_examples_xx_applications_plot_thresholding.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/xx_applications/plot_thresholding

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Haar-like feature descriptors were successfully used to implement the first real-time face dete...">

.. only:: html

    .. figure:: /auto_examples/xx_applications/images/thumb/sphx_glr_plot_haar_extraction_selection_classification_thumb.png

        :ref:`sphx_glr_auto_examples_xx_applications_plot_haar_extraction_selection_classification.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/xx_applications/plot_haar_extraction_selection_classification

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Rank filters are non-linear filters using the local gray-level ordering to compute the filtered...">

.. only:: html

    .. figure:: /auto_examples/xx_applications/images/thumb/sphx_glr_plot_rank_filters_thumb.png

        :ref:`sphx_glr_auto_examples_xx_applications_plot_rank_filters.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/xx_applications/plot_rank_filters
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip <//home/egor/Workspace/_contrib/scikit-image/doc/source/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip <//home/egor/Workspace/_contrib/scikit-image/doc/source/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
